@@ -20,6 +20,7 @@ import sys
 from oslo_concurrency import processutils
 from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
+from oslo_reports import opts as gmr_opts
 from oslo_service import service
 
 from magnum.common import rpc_service
@@ -28,7 +29,9 @@ from magnum.common import short_id
 from magnum.conductor.handlers import ca_conductor
 from magnum.conductor.handlers import cluster_conductor
 from magnum.conductor.handlers import conductor_listener
+from magnum.conductor.handlers import federation_conductor
 from magnum.conductor.handlers import indirection_api
+from magnum.conductor.handlers import nodegroup_conductor
 import magnum.conf
 from magnum import version
 
@@ -39,7 +42,8 @@ LOG = logging.getLogger(__name__)
 def main():
     magnum_service.prepare_service(sys.argv)
 
-    gmr.TextGuruMeditation.setup_autorun(version)
+    gmr_opts.set_defaults(CONF)
+    gmr.TextGuruMeditation.setup_autorun(version, conf=CONF)
 
     LOG.info('Starting server in PID %s', os.getpid())
     LOG.debug("Configuration:")
@@ -51,6 +55,8 @@ def main():
         cluster_conductor.Handler(),
         conductor_listener.Handler(),
         ca_conductor.Handler(),
+        federation_conductor.Handler(),
+        nodegroup_conductor.Handler(),
     ]
 
     server = rpc_service.Service.create(CONF.conductor.topic,
