@@ -24,7 +24,6 @@ import sys
 from keystoneclient import exceptions as keystone_exceptions
 from oslo_config import cfg
 from oslo_log import log as logging
-import six
 
 import magnum.conf
 from magnum.i18n import _
@@ -104,9 +103,7 @@ class MagnumException(Exception):
         super(MagnumException, self).__init__(self.message)
 
     def __str__(self):
-        if six.PY3:
-            return self.message
-        return self.message.encode('utf-8')
+        return self.message
 
     def __unicode__(self):
         return self.message
@@ -115,7 +112,7 @@ class MagnumException(Exception):
         if self.__class__.__name__.endswith('_Remote'):
             return self.args[0]
         else:
-            return six.text_type(self)
+            return str(self)
 
 
 class ObjectNotFound(MagnumException):
@@ -270,6 +267,10 @@ class ClusterTypeNotSupported(NotSupported):
                 " not supported.")
 
 
+class ClusterDriverNotSupported(NotSupported):
+    message = _("Cluster driver (%(driver_name)s) not supported.")
+
+
 class RequiredParameterNotProvided(Invalid):
     message = _("Required parameter %(heat_param)s not provided.")
 
@@ -333,10 +334,6 @@ class UnsupportedK8sQuantityFormat(Invalid):
     message = _("Unsupported quantity format for k8s cluster.")
 
 
-class UnsupportedDockerQuantityFormat(Invalid):
-    message = _("Unsupported quantity format for Swarm cluster.")
-
-
 class FlavorNotFound(ResourceNotFound):
     """The code here changed to 400 according to the latest document."""
     message = _("Unable to find flavor %(flavor)s.")
@@ -437,8 +434,14 @@ class NodeGroupNotFound(ResourceNotFound):
     message = _("Nodegroup %(nodegroup)s could not be found.")
 
 
+class MasterNGSizeInvalid(InvalidParameterValue):
+    message = _("master nodegroup size of %(requested_size)s is invalid, "
+                "size cannot be an even number.")
+
+
 class MasterNGResizeNotSupported(NotSupported):
-    message = _("Resizing a master nodegroup is not supported.")
+    message = _("Resizing the master nodegroup is not supported "
+                "by this driver.")
 
 
 class ZeroNodeCountNotSupported(NotSupported):
@@ -480,3 +483,8 @@ class InvalidClusterTemplateForUpgrade(Conflict):
 
 class ClusterAPIAddressUnavailable(Conflict):
     message = _("Cluster API address is not available yet")
+
+
+class ObjectError(MagnumException):
+    message = _("Failed to perform action %{action}s on %{obj_name}s with "
+                "uuid %{obj_id}s: %{reason}s")
