@@ -18,5 +18,10 @@ class TestKubernetesAPIs(base.BaseK8sTest):
         "tls_disabled": False,
         "network_driver": 'flannel',
         "volume_driver": 'cinder',
-        "fixed_network": '192.168.0.0/24'
+        "docker_storage_driver": 'overlay',
+        "labels": {
+            "system_pods_initial_delay": 3600,
+            "system_pods_timeout": 600,
+            "kube_dashboard_enabled": False,
+        }
     }
